@@ -6,9 +6,5 @@ setMethod(f = "coef", signature(object = "glimQL"), definition = function(object
 
 ## model coefficients for class glimML (functions betabin and betapois)
 setMethod(f = "coef", signature = "glimML", function(object, ...) {
-  f <- object@formula[-2]
-  mm <- model.matrix(f, data = object@data)
-  v <- object@param[seq(ncol(mm))]
-  names(v) <- colnames(mm)
-  v
+  object@fixed.param
   })
